[PATCH,committed] AIX32 libffi typo fix

David Edelsohn dje.gcc@gmail.com
Tue Dec 8 00:46:00 GMT 2009


I missed a line when converting the AIX32 code to match the AIX64 code
and inadvertently tested the 64 bit multilib twice because of DejaGNU
harness problems on AIX.

David

Index: aix_closure.S
===================================================================
--- aix_closure.S       (revision 155030)
+++ aix_closure.S       (working copy)
@@ -340,7 +340,7 @@
        lwz     r4, LC..60(2)   /* get address of jump table */
        slwi    r3, r3, 4       /* now multiply return type by 4 */
        lwz     r0, 176+8(r1)   /* load return address */
-       lwzx    r3, r4, r3      /* get the contents of that table value */
+       add     r3, r3, r4      /* add contents of table to table address */
        mtctr   r3
        bctr                    /* jump to it */



More information about the Gcc-patches mailing list